==> dojo-1.10.6.tgz: package/cldr/nls/sr/islamic.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"не",
		"по",
		"ут",
		"ср",
		"че",
		"пе",
		"су"
	],
	"field-second-relative+0": "сада",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-weekday": "дан у недељи",
	"field-wed-relative+0": "ове среде",
	"field-wed-relative+1": "следеће среде",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"eraNarrow": [
		"АХ"
	],
	"field-tue-relative+-1": "прошлог уторка",
	"days-format-short": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormat-long": "dd. MMMM y. G",
	"field-fri-relative+-1": "прошлог петка",
	"field-wed-relative+-1": "прошле среде",
	"months-format-wide": [
		"Мурахам",
		"Сафар",
		"Рабиʻ I",
		"Рабиʻ II",
		"Јумада I",
		"Јумада II",
		"Рађаб",
		"Шаʻбан",
		"Рамадан",
		"Шавал",
		"Дуʻл-Киʻда",
		"Дуʻл-хиђа"
	],
	"dateFormatItem-yyyyQQQ": "QQQ, y. G",
	"dayPeriods-format-wide-pm": "поподне",
	"dateFormat-full": "EEEE, dd. MMMM y. G",
	"dateFormatItem-yyyyMEd": "E, d.M.y. G",
	"field-thu-relative+-1": "прошлог четвртка",
	"dateFormatItem-Md": "d/M",
	"field-era": "ера",
	"months-standAlone-wide": [
		"Мурахам",
		"Сафар",
		"Рабиʻ I",
		"Рабиʻ II",
		"Јумада I",
		"Јумада II",
		"Рађаб",
		"Шаʻбан",
		"Рамадан",
		"Шавал",
		"Дуʻл-Киʻда",
		"Дуʻл-хиђа"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"Прво тромесечје",
		"Друго тромесечје",
		"Треће тромесечје",
		"Четврто тромесечје"
	],
	"timeFormat-long": "HH.mm.ss z",
	"field-year": "година",
	"field-hour": "час",
	"months-format-abbr": [
		"Мурахам",
		"Сафар",
		"Рабиʻ I",
		"Рабиʻ II",
		"Јумада I",
		"Јумада II",
		"Рађаб",
		"Шаʻбан",
		"Рамадан",
		"Шавал",
		"Дуʻл-Киʻда",
		"Дуʻл-хиђа"
	],
	"field-sat-relative+0": "ове суботе",
	"field-sat-relative+1": "следеће суботе",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "данас",
	"field-thu-relative+0": "овог четвртка",
	"field-day-relative+1": "сутра",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "прекосутра",
	"months-standAlone-abbr": [
		"Мурахам",
		"Сафар",
		"Рабиʻ I",
		"Рабиʻ II",
		"Јумада I",
		"Јумада II",
		"Рађаб",
		"Шаʻбан",
		"Рамадан",
		"Шавал",
		"Дуʻл-Киʻда",
		"Дуʻл-хиђа"
	],
	"quarters-format-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"quarters-standAlone-wide": [
		"Прво тромесечје",
		"Друго тромесечје",
		"Треће тромесечје",
		"Четврто тромесечје"
	],
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"days-standAlone-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "ове недеље",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "следеће недеље",
	"quarters-standAlone-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"eraAbbr": [
		"АХ"
	],
	"field-minute": "минут",
	"field-dayperiod": "пре подне/поподне",
	"days-standAlone-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormatItem-ms": "mm.ss",
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-day-relative+-1": "јуче",
	"dateFormatItem-h": "hh a",
	"field-day-relative+-2": "прекјуче",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, M-d",
	"field-fri-relative+0": "овог петка",
	"field-fri-relative+1": "следећег петка",
	"field-day": "дан",
	"days-format-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"field-zone": "зона",
	"dateFormatItem-y": "y. G",
	"field-year-relative+-1": "Прошле године",
	"field-month-relative+-1": "Прошлог месеца",
	"dateFormatItem-hm": "hh.mm a",
	"days-format-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"eraNames": [
		"АХ"
	],
	"days-format-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"dateFormatItem-yyyyMd": "d.M.y. G",
	"field-month": "месец",
	"days-standAlone-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"field-tue-relative+0": "овог уторка",
	"field-tue-relative+1": "следећег уторка",
	"dayPeriods-format-wide-am": "пре подне",
	"field-mon-relative+0": "овог понедељка",
	"field-mon-relative+1": "следећег понедељка",
	"dateFormat-short": "d.M.y. GGGGG",
	"field-second": "секунд",
	"field-sat-relative+-1": "прошле суботе",
	"field-sun-relative+-1": "прошле недеље",
	"field-month-relative+0": "Овог месеца",
	"field-month-relative+1": "Следећег месеца",
	"dateFormatItem-Ed": "E d.",
	"field-week": "недеља",
	"dateFormat-medium": "dd.MM.y. G",
	"field-year-relative+0": "Ове године",
	"field-week-relative+-1": "Прошле недеље",
	"dateFormatItem-yyyyM": "M.y. G",
	"field-year-relative+1": "Следеће године",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "hh.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-mon-relative+-1": "прошлог понедељка",
	"dateFormatItem-yyyy": "y. G",
	"field-week-relative+0": "Ове недеље",
	"field-week-relative+1": "Следеће недеље"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/sr/islamic.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"не",
		"по",
		"ут",
		"ср",
		"че",
		"пе",
		"су"
	],
	"field-second-relative+0": "сада",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-weekday": "дан у недељи",
	"field-wed-relative+0": "у среду",
	"field-wed-relative+1": "следеће среде",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"eraNarrow": [
		"АХ"
	],
	"field-tue-relative+-1": "прошлог уторка",
	"days-format-short": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormat-long": "dd. MMMM y. G",
	"field-fri-relative+-1": "прошлог петка",
	"field-wed-relative+-1": "прошле среде",
	"months-format-wide": [
		"Мурахам",
		"Сафар",
		"Рабиʻ I",
		"Рабиʻ II",
		"Јумада I",
		"Јумада II",
		"Рађаб",
		"Шаʻбан",
		"Рамадан",
		"Шавал",
		"Дуʻл-Киʻда",
		"Дуʻл-хиђа"
	],
	"dateFormatItem-yyyyQQQ": "QQQ, y. G",
	"dayPeriods-format-wide-pm": "по подне",
	"dateFormat-full": "EEEE, dd. MMMM y. G",
	"dateFormatItem-yyyyMEd": "E, d.M.y. G",
	"field-thu-relative+-1": "прошлог четвртка",
	"dateFormatItem-Md": "d/M",
	"field-era": "ера",
	"months-standAlone-wide": [
		"Мурахам",
		"Сафар",
		"Рабиʻ I",
		"Рабиʻ II",
		"Јумада I",
		"Јумада II",
		"Рађаб",
		"Шаʻбан",
		"Рамадан",
		"Шавал",
		"Дуʻл-Киʻда",
		"Дуʻл-хиђа"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"Прво тромесечје",
		"Друго тромесечје",
		"Треће тромесечје",
		"Четврто тромесечје"
	],
	"timeFormat-long": "HH.mm.ss z",
	"field-year": "година",
	"field-hour": "сат",
	"months-format-abbr": [
		"Мурахам",
		"Сафар",
		"Рабиʻ I",
		"Рабиʻ II",
		"Јумада I",
		"Јумада II",
		"Рађаб",
		"Шаʻбан",
		"Рамадан",
		"Шавал",
		"Дуʻл-Киʻда",
		"Дуʻл-хиђа"
	],
	"field-sat-relative+0": "у суботу",
	"field-sat-relative+1": "следеће суботе",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "данас",
	"field-thu-relative+0": "у четвртак",
	"field-day-relative+1": "сутра",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "прекосутра",
	"months-standAlone-abbr": [
		"Мурахам",
		"Сафар",
		"Рабиʻ I",
		"Рабиʻ II",
		"Јумада I",
		"Јумада II",
		"Рађаб",
		"Шаʻбан",
		"Рамадан",
		"Шавал",
		"Дуʻл-Киʻда",
		"Дуʻл-хиђа"
	],
	"quarters-format-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"quarters-standAlone-wide": [
		"Прво тромесечје",
		"Друго тромесечје",
		"Треће тромесечје",
		"Четврто тромесечје"
	],
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"days-standAlone-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "у недељу",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "следеће недеље",
	"quarters-standAlone-abbr": [
		"К1",
		"К2",
		"К3",
		"К4"
	],
	"eraAbbr": [
		"АХ"
	],
	"field-minute": "минут",
	"field-dayperiod": "пре подне/по подне",
	"days-standAlone-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"dateFormatItem-ms": "mm.ss",
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-day-relative+-1": "јуче",
	"dateFormatItem-h": "hh a",
	"field-day-relative+-2": "прекјуче",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, M-d",
	"field-fri-relative+0": "у петак",
	"field-fri-relative+1": "следећег петка",
	"field-day": "дан",
	"days-format-wide": [
		"недеља",
		"понедељак",
		"уторак",
		"среда",
		"четвртак",
		"петак",
		"субота"
	],
	"field-zone": "временска зона",
	"dateFormatItem-y": "y. G",
	"field-year-relative+-1": "прошле године",
	"field-month-relative+-1": "прошлог месеца",
	"dateFormatItem-hm": "hh.mm a",
	"days-format-abbr": [
		"нед",
		"пон",
		"уто",
		"сре",
		"чет",
		"пет",
		"суб"
	],
	"eraNames": [
		"АХ"
	],
	"days-format-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"dateFormatItem-yyyyMd": "d.M.y. G",
	"field-month": "месец",
	"days-standAlone-narrow": [
		"н",
		"п",
		"у",
		"с",
		"ч",
		"п",
		"с"
	],
	"field-tue-relative+0": "у уторак",
	"field-tue-relative+1": "следећег уторка",
	"dayPeriods-format-wide-am": "пре подне",
	"field-mon-relative+0": "у понедељак",
	"field-mon-relative+1": "следећег понедељка",
	"dateFormat-short": "d.M.y. GGGGG",
	"field-second": "секунд",
	"field-sat-relative+-1": "прошле суботе",
	"field-sun-relative+-1": "прошле недеље",
	"field-month-relative+0": "овог месеца",
	"field-month-relative+1": "следећег месеца",
	"dateFormatItem-Ed": "E d.",
	"field-week": "недеља",
	"dateFormat-medium": "dd.MM.y. G",
	"field-year-relative+0": "ове године",
	"field-week-relative+-1": "прошле недеље",
	"dateFormatItem-yyyyM": "M.y. G",
	"field-year-relative+1": "следеће године",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "hh.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-mon-relative+-1": "прошлог понедељка",
	"dateFormatItem-yyyy": "y. G",
	"field-week-relative+0": "ове недеље",
	"field-week-relative+1": "следеће недеље"
}
//end v1.x content
);
